@@ -1,7 +1,7 @@
 /* 
  * mumudvb - UDP-ize a DVB transport stream.
  * 
- * (C) 2004-2008 Brice DUBOST
+ * (C) 2004-2009 Brice DUBOST
  * 
  * The latest version can be found at http://mumudvb.braice.net
  * 
@@ -23,6 +23,11 @@
  *     
  */
 
+/**@file
+ *File for the enumeration of the different possible errors
+ *@todo : update it 
+ */
+
 #ifndef _ERRORS_MUMUDVB_H
 #define _ERRORS_MUMUDVB_H
 
